@@ -29,6 +29,20 @@ class JyInterface(object):
     def sleep(self, n):
         time.sleep(n)
     
+    def logPrint(self, msg):
+        try:
+            self.stub.addTradeLog(common_pb2.LogRequest(transferId=self.transferId,
+                                                        msg=msg))
+        except:
+            print(msg)
+
+    def stopStrategy(self):
+        try:
+            self.stub.stopStrategy(common_pb2.StopRequest(transferId=self.transferId)) 
+        except:
+            print('------stopStrategy------')
+            sys.exit(0)    
+
     def getKline(self, symbol, klinePeriod, size):
         pType = "" # fixed return all 
         response = self.stub.getKline(common_pb2.KlineRequest(type=self.type_,
@@ -215,7 +229,7 @@ class JyInterface(object):
             elif tmstr[0] == 'm' and (tm.tm_min % tmnum != 0 or tm.tm_sec != 0):
                 return
             elif tmstr[0] == 'd' and (tm.tm_hour != 0 or tm.tm_min != 0 or tm.tm_sec != 0):
-                return            
+                return
             self.loop()
         except:
             pass
